@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2020 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -18,32 +18,28 @@
 DWIDGET_USE_NAMESPACE
 typedef DLabel QLbtoDLabel;
 
-//class DBaseExpand;
 class QFormLayout;
 class QVBoxLayout;
 class ViewSeparator;
+
 class LibImageInfoWidget : public QFrame
 {
     Q_OBJECT
 public:
-    explicit LibImageInfoWidget(const QString &darkStyle,
-                                const QString &lightStyle,
-                                QWidget *parent = nullptr);
+    explicit LibImageInfoWidget(const QString &darkStyle, const QString &lightStyle, QWidget *parent = nullptr);
     ~LibImageInfoWidget() Q_DECL_OVERRIDE;
-    void setImagePath(const QString path);
+    void setImagePath(const QString &path, bool forceUpdate = true);
     void updateInfo();
     int contentHeight() const;
-//    QSize sizeHint() const override;
 
 signals:
     void extensionPanelHeight(int height);
-public slots:
-//    void onExpandChanged(const bool &e);
 
 protected:
     void resizeEvent(QResizeEvent *e) Q_DECL_OVERRIDE;
     void timerEvent(QTimerEvent *e) Q_DECL_OVERRIDE;
     void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+
 private:
     void clearLayout(QLayout *layout);
     const QString trLabel(const char *str);
@@ -54,12 +50,13 @@ private:
 
 private:
     int m_updateTid = 0;
-    int m_maxTitleWidth;  //For align colon
+    int m_maxTitleWidth;  // For align colon
     int m_maxFieldWidth;
-    int m_currentFontSize; //LMH0609上次显示的字体大小
+    int m_currentFontSize;  // LMH0609上次显示的字体大小
     bool m_isBaseInfo = false;
     bool m_isDetailsInfo = false;
     QString m_path;
+    QMap<QString, QString> m_metaData;
     QFrame *m_exif_base = nullptr;
     QFrame *m_exif_details = nullptr;
     QFormLayout *m_exifLayout_base = nullptr;
@@ -71,4 +68,4 @@ private:
     QString m_closedString;
 };
 
-#endif // IMAGEINFOWIDGET_H
+#endif  // IMAGEINFOWIDGET_H
